# SearchSource: OpenLibrary

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): search updates, get_masterdata, run_search, load_fixes, prep

[OpenLibrary](https://openlibrary.org/)

## Add the search source

Searches of the OpenLibrary are not (yet) supported.

## Links
